@@ -2,7 +2,7 @@ import unittest
 
 import responses
 
-from securenative.config.configuration_manager import ConfigurationManager
+from securenative.config.securenative_options import SecureNativeOptions
 from securenative.http.securenative_http_client import SecureNativeHttpClient
 
 
@@ -10,9 +10,8 @@ class SecureNativeHttpClientTest(unittest.TestCase):
 
     @responses.activate
     def test_should_make_simple_post_call(self):
-        options = ConfigurationManager.config_builder(). \
-            with_api_key("YOUR_API_KEY").\
-            with_api_url("https://api.securenative-stg.com/collector/api/v1")
+        options = SecureNativeOptions(api_key="YOUR_API_KEY", auto_send=True, interval=10,
+                                      api_url="https://api.securenative-stg.com/collector/api/v1")
 
         responses.add(responses.POST, "https://api.securenative-stg.com/collector/api/v1/track",
                       json={"event": "SOME_EVENT_NAME"}, status=200)
